@@ -4,15 +4,16 @@
 import json
 import os
 
-from beancount.query import query_env
-from beancount.query import query_parser
 import click
 import requests
+from beancount.query import query_env
+from beancount.query import query_parser
+
+from fava import LOCALES
 
 BASE_PATH = os.path.normpath(
     os.path.join(os.path.dirname(__file__), "../fava")
 )
-LANGUAGES = ["de", "es", "fr", "nl", "pt", "ru", "zh-CN", "sk", "uk"]
 
 
 @click.group()
@@ -46,7 +47,7 @@ def generate_bql_grammar_json():
         os.path.dirname(__file__),
         "../fava/static/javascript/codemirror/bql-grammar.json",
     )
-    with open(path, "w") as json_file:
+    with open(path, "w", encoding="utf-8") as json_file:
         json.dump(data, json_file)
 
 
@@ -58,9 +59,8 @@ def download_translations():
         raise click.UsageError(
             "The POEDITOR_TOKEN environment variable needs to be set."
         )
-    for language in LANGUAGES:
-        download_from_poeditor(language, "po", token)
-        download_from_poeditor(language, "mo", token)
+    for language in LOCALES:
+        download_from_poeditor(language, token)
 
 
 @cli.command()
@@ -77,7 +77,7 @@ def upload_translations():
         "api_token": token,
         "id": 90283,
         "updating": "terms",
-        "sync_terms": 1,
+        # "sync_terms": 1,
     }
     files = {"file": open(path, "rb")}
     request = requests.post(
@@ -86,27 +86,29 @@ def upload_translations():
     click.echo("Done: " + str(request.json()["result"]["terms"]))
 
 
-def download_from_poeditor(language, format_, token):
-    """Download .{po,mo}-file from POEditor and save to disk."""
-    click.echo(f'Downloading .{format_}-file for language "{language}"')
-    language_short = language[:2]
+# For these languages, the name on POEDITOR is off.
+POEDITOR_LANGUAGE_NAME = {"zh": "zh-CN", "zh_Hant_TW": "zh-TW"}
+
+
+def download_from_poeditor(language, token):
+    """Download .po-file from POEditor and save to disk."""
+    click.echo(f'Downloading .po-file for language "{language}"')
+    poeditor_name = POEDITOR_LANGUAGE_NAME.get(language, language)
     data = {
         "api_token": token,
         "id": 90283,
-        "language": language,
-        "type": format_,
+        "language": poeditor_name,
+        "type": "po",
     }
     request = requests.post(
         "https://api.poeditor.com/v2/projects/export", data=data
     )
     url = request.json()["result"]["url"]
     content = requests.get(url).content
-    folder = os.path.join(
-        BASE_PATH, "translations", language_short, "LC_MESSAGES"
-    )
+    folder = os.path.join(BASE_PATH, "translations", language, "LC_MESSAGES")
     if not os.path.exists(folder):
         os.makedirs(folder)
-    path = os.path.join(folder, f"messages.{format_}")
+    path = os.path.join(folder, f"messages.po")
     with open(path, "wb") as file_:
         file_.write(content)
     click.echo(f'Downloaded to "{path}"')
