@@ -1,9 +1,10 @@
-# pylint: disable=invalid-name
+# pylint: disable=invalid-name,missing-docstring
 
 extensions = [
     "sphinx.ext.extlinks",
-    "sphinx.ext.autodoc",
     "sphinx.ext.napoleon",
+    "sphinx.ext.autodoc",
+    "sphinx_autodoc_typehints",
 ]
 source_suffix = ".rst"
 master_doc = "index"
@@ -23,6 +24,17 @@ extlinks = {
 
 autodoc_default_flags = ["members", "undoc-members"]
 
+
+def skip_namedtuples(_app, _what, _name, obj, _options, _lines):
+    if obj.__doc__ and obj.__doc__.startswith("Alias for field number"):
+        return True
+    return None
+
+
+def setup(app):
+    app.connect("autodoc-skip-member", skip_namedtuples)
+
+
 # Options for HTML output
 html_theme = "alabaster"
 html_static_path = ["static"]
@@ -37,6 +49,7 @@ html_theme_options = {
     "show_powered_by": "false",
     "extra_nav_links": {
         "fava @ GitHub": "https://github.com/beancount/fava",
+        "Chat": "https://gitter.im/beancount/fava",
         "Issue Tracker": "https://github.com/beancount/fava/issues",
     },
     "link": "#3572b0",
