@@ -30,7 +30,7 @@ from flask import (
     render_template_string,
 )
 import flask
-from flask_babel import Babel
+from flask_babel import Babel, get_translations
 import markdown2
 import werkzeug.urls
 from werkzeug.utils import secure_filename
@@ -38,7 +38,7 @@ from beancount.utils.text_utils import replace_numbers
 from beancount.core.data import Document
 from beancount.core.account import ACCOUNT_RE
 
-from fava import template_filters
+from fava import template_filters, LANGUAGES
 from fava.core import FavaLedger
 from fava.core.charts import FavaJSONEncoder
 from fava.core.helpers import FavaAPIException
@@ -49,7 +49,6 @@ from fava.util import slugify, resource_path, setup_logging, send_file_inline
 from fava.util.date import Interval
 from fava.util.excel import HAVE_EXCEL
 
-
 setup_logging()
 app = Flask(  # pylint: disable=invalid-name
     __name__,
@@ -74,7 +73,6 @@ REPORTS = [
     "events",
     "editor",
     "errors",
-    "extract",
     "holdings",
     "import",
     "income_statement",
@@ -117,9 +115,7 @@ def get_locale():
     """
     if g.ledger.fava_options["language"]:
         return g.ledger.fava_options["language"]
-    return request.accept_languages.best_match(
-        ["de", "en", "es", "zh", "nl", "fr", "pt", "sk", "uk"]
-    )
+    return request.accept_languages.best_match(["en"] + LANGUAGES)
 
 
 for _, function in inspect.getmembers(template_filters, inspect.isfunction):
@@ -192,7 +188,9 @@ def url_for_source(**kwargs):
 @app.context_processor
 def template_context():
     """Inject variables into the template context."""
-    return dict(ledger=g.ledger)
+    # pylint: disable=protected-access
+    catalog = get_translations()._catalog
+    return dict(ledger=g.ledger, translations=catalog)
 
 
 @app.before_request
@@ -273,14 +271,18 @@ def account(name, subreport="journal"):
 def document():
     """Download a document."""
     filename = request.args.get("filename")
-    if not any(
-        (
-            filename == document.filename
-            for document in g.ledger.all_entries_by_type[Document]
-        )
-    ):
-        abort(404)
-    return send_file_inline(filename)
+    filenames = [
+        document.filename
+        for document in g.ledger.all_entries_by_type[Document]
+    ]
+    import_directories = [
+        g.ledger.join_path(d) for d in g.ledger.fava_options["import-dirs"]
+    ]
+    if filename in filenames:
+        return send_file_inline(filename)
+    if any(filename.startswith(d) for d in import_directories):
+        return send_file_inline(filename)
+    return abort(404)
 
 
 @app.route("/<bfile>/statement/", methods=["GET"])
@@ -297,19 +299,46 @@ def holdings_by(aggregation_key):
     """The holdings report."""
     if aggregation_key in ["account", "currency", "cost_currency"]:
         return render_template(
-            "holdings.html", aggregation_key=aggregation_key
+            "_layout.html",
+            active_page="holdings",
+            aggregation_key=aggregation_key,
         )
-    abort(404)
-    return None
+    return abort(404)
+
+
+@app.route("/<bfile>/_context/")
+def context():
+    """Entry context."""
+    return render_template("_context.html")
+
+
+@app.route("/<bfile>/query/")
+def query():
+    """Query shell."""
+    return render_template("query.html")
 
 
 @app.route("/<bfile>/<report_name>/")
 def report(report_name):
     """Endpoint for most reports."""
     if report_name in REPORTS:
-        return render_template("{}.html".format(report_name))
-    abort(404)
-    return None
+        return render_template("_layout.html", active_page=report_name)
+    return abort(404)
+
+
+@app.route("/<bfile>/extension/<report_name>/")
+def extension_report(report_name):
+    """Endpoint for extension reports."""
+    try:
+        template, extension = g.ledger.extensions.template_and_extension(
+            report_name
+        )
+        content = render_template_string(template, extension=extension)
+        return render_template(
+            "_layout.html", content=content, page_title=extension.report_title
+        )
+    except LookupError:
+        return abort(404)
 
 
 @app.route("/<bfile>/download-query/query_result.<result_format>")
@@ -343,7 +372,8 @@ def help_page(page_slug="_index"):
         extras=["fenced-code-blocks", "tables"],
     )
     return render_template(
-        "help.html",
+        "_layout.html",
+        active_page="help",
         page_slug=page_slug,
         help_html=render_template_string(html),
     )
