@@ -13,7 +13,7 @@ from fava import __version__
 
 
 # pylint: disable=too-many-arguments
-@click.command()
+@click.command(context_settings=dict(auto_envvar_prefix="FAVA"))
 @click.argument(
     "filenames",
     nargs=-1,
@@ -24,24 +24,24 @@ from fava import __version__
     "--port",
     type=int,
     default=5000,
+    show_default=True,
     metavar="<port>",
-    help="The port to listen on. (default: 5000)",
+    help="The port to listen on.",
 )
 @click.option(
     "-H",
     "--host",
     type=str,
     default="localhost",
+    show_default=True,
     metavar="<host>",
-    help="The host to listen on. (default: localhost)",
-)
-@click.option(
-    "--prefix", type=str, help="Set an URL prefix. (for reverse proxy)"
+    help="The host to listen on.",
 )
+@click.option("--prefix", type=str, help="Set an URL prefix.")
 @click.option(
     "--incognito",
     is_flag=True,
-    help="Run in incognito mode (obscure all numbers).",
+    help="Run in incognito mode and obscure all numbers.",
 )
 @click.option("-d", "--debug", is_flag=True, help="Turn on debugging.")
 @click.option(
@@ -60,6 +60,10 @@ def main(
 
     If the `BEANCOUNT_FILE` environment variable is set, Fava will use the
     files (space-delimited) specified there in addition to FILENAMES.
+
+    Note you can also specify command-line options via environment variables.
+    For example, `--host=0.0.0.0` is equivalent to setting the environment
+    variable `FAVA_HOST=0.0.0.0`.
     """
 
     if profile:  # pragma: no cover
@@ -104,8 +108,7 @@ def main(
                     "Can not start webserver because the port is already in "
                     "use. Please choose another port with the '-p' option."
                 )
-            else:  # pragma: no cover
-                raise
+            raise
 
 
 # needed for pyinstaller:
