@@ -3,14 +3,14 @@
 import os
 
 
-class Watcher():
+class Watcher:
     """A simple file and folder watcher.
 
     For folders, only checks mtime of the folder and all subdirectories.
     So a file change won't be noticed, but only new/deleted files.
     """
 
-    __slots__ = ['_files', '_folders', '_last_checked']
+    __slots__ = ["_files", "_folders", "_last_checked"]
 
     def __init__(self):
         self._files = []
