@@ -13,6 +13,7 @@ import re
 
 from beancount.core import data, position
 from beancount.core.amount import A, Amount
+from beancount.core.data import EMPTY_SET
 from beancount.core.number import D, MISSING
 
 from fava import util
@@ -31,6 +32,9 @@ def extract_tags_links(string):
         stripped of tags and links.
     """
 
+    if string is None:
+        return None, EMPTY_SET, EMPTY_SET
+
     tags = re.findall(r"(?:^|\s)#([A-Za-z0-9\-_/.]+)", string)
     links = re.findall(r"(?:^|\s)\^([A-Za-z0-9\-_/.]+)", string)
     new_string = re.sub(r"(?:^|\s)[#^]([A-Za-z0-9\-_/.]+)", "", string).strip()
@@ -115,8 +119,8 @@ def deserialise(json_entry):
         return data.Transaction(
             json_entry["meta"],
             date,
-            json_entry["flag"],
-            json_entry["payee"],
+            json_entry.get("flag", ""),
+            json_entry.get("payee", ""),
             narration,
             tags,
             links,
@@ -124,8 +128,8 @@ def deserialise(json_entry):
         )
     if json_entry["type"] == "Balance":
         date = util.date.parse_date(json_entry["date"])[0]
-        number = parse_number(json_entry["number"])
-        amount = Amount(number, json_entry["currency"])
+        raw_amount = json_entry["amount"]
+        amount = Amount(D(raw_amount["number"]), raw_amount["currency"])
 
         return data.Balance(
             json_entry["meta"], date, json_entry["account"], amount, None, None
