@@ -182,3 +182,16 @@ def format_errormsg(message):
         .replace("for '", "for ")
         .replace("': ", ": ")
     )
+
+
+def collapse_account(account_name):
+    """Return true if account should be collapsed."""
+    collapse_patterns = g.ledger.fava_options["collapse-pattern"]
+    for pattern in collapse_patterns:
+        try:
+            if re.match(pattern, account_name):
+                return True
+        except re.error:
+            pass
+
+    return False
