@@ -1,3 +1,5 @@
+# pylint: disable=missing-docstring
+
 import datetime
 from textwrap import dedent
 import re
@@ -34,16 +36,16 @@ def test_save_entry_slice(example_ledger):
     new_source = """2016-05-03 * "Chichipotle" "Eating out with Joe"
   Expenses:Food:Restaurant                          21.70 USD"""
     filename = entry.meta["filename"]
-    contents = open(filename).read()
+    contents = open(filename, encoding="utf-8").read()
 
     with pytest.raises(FavaAPIException):
         save_entry_slice(entry, new_source, "wrong hash")
-        assert open(filename).read() == contents
+        assert open(filename, encoding="utf-8").read() == contents
 
     new_sha256sum = save_entry_slice(entry, new_source, sha256sum)
-    assert open(filename).read() != contents
+    assert open(filename, encoding="utf-8").read() != contents
     sha256sum = save_entry_slice(entry, entry_source, new_sha256sum)
-    assert open(filename).read() == contents
+    assert open(filename, encoding="utf-8").read() == contents
 
 
 def test_next_key():
@@ -130,7 +132,7 @@ def test_insert_entry_transaction(tmpdir):
     ]
 
     transaction = data.Transaction(
-        None,
+        {},
         datetime.date(2016, 1, 1),
         "*",
         "new payee",
@@ -140,6 +142,7 @@ def test_insert_entry_transaction(tmpdir):
         postings,
     )
 
+    # Test insertion without "insert-entry" options.
     insert_entry(transaction, [str(samplefile)], {})
     assert samplefile.read() == dedent(
         """
@@ -154,6 +157,8 @@ def test_insert_entry_transaction(tmpdir):
     """
     )
 
+    # Verify that InsertEntryOptions with dates greater or equal than the
+    # transaction dates are ignored.
     options = [
         InsertEntryOption(
             datetime.date(2015, 1, 1),
@@ -174,10 +179,11 @@ def test_insert_entry_transaction(tmpdir):
             6,
         ),
     ]
+    transaction = transaction._replace(narration="narr1")
     insert_entry(transaction, [str(samplefile)], {"insert-entry": options})
     assert samplefile.read() == dedent(
         """
-        2016-01-01 * "new payee" "narr"
+        2016-01-01 * "new payee" "narr1"
           Liabilities:US:Chase:Slate                         -10.00 USD
           Expenses:Food                                       10.00 USD
 
@@ -192,12 +198,14 @@ def test_insert_entry_transaction(tmpdir):
     """
     )
 
+    # Verify that previous postings are matched against InsertEntryOptions when
+    # the last posting doesn't match.
     options = [
         InsertEntryOption(
             datetime.date(2015, 1, 1),
             re.compile(".*:Slate"),
             str(samplefile),
-            5,
+            6,
         ),
         InsertEntryOption(
             datetime.date(2015, 1, 2),
@@ -206,16 +214,60 @@ def test_insert_entry_transaction(tmpdir):
             2,
         ),
     ]
+    transaction = transaction._replace(narration="narr2")
     insert_entry(transaction, [str(samplefile)], {"insert-entry": options})
     assert samplefile.read() == dedent(
         """
-        2016-01-01 * "new payee" "narr"
+        2016-01-01 * "new payee" "narr1"
           Liabilities:US:Chase:Slate                         -10.00 USD
           Expenses:Food                                       10.00 USD
+
+        2016-01-01 * "new payee" "narr2"
+          Liabilities:US:Chase:Slate                         -10.00 USD
+          Expenses:Food                                       10.00 USD
+
+        2016-02-26 * "Uncle Boons" "Eating out alone"
+            Liabilities:US:Chase:Slate                       -24.84 USD
+            Expenses:Food:Restaurant                          24.84 USD
+
         2016-01-01 * "new payee" "narr"
           Liabilities:US:Chase:Slate                         -10.00 USD
           Expenses:Food                                       10.00 USD
 
+    """
+    )
+
+    # Verify that preference is given to InsertEntryOptions with later dates in
+    # case several of them match a posting.
+    options = [
+        InsertEntryOption(
+            datetime.date(2015, 1, 1),
+            re.compile(".*:Food"),
+            str(samplefile),
+            6,
+        ),
+        InsertEntryOption(
+            datetime.date(2015, 1, 2),
+            re.compile(".*:Food"),
+            str(samplefile),
+            2,
+        ),
+    ]
+    transaction = transaction._replace(narration="narr3")
+    insert_entry(transaction, [str(samplefile)], {"insert-entry": options})
+    assert samplefile.read() == dedent(
+        """
+        2016-01-01 * "new payee" "narr3"
+          Liabilities:US:Chase:Slate                         -10.00 USD
+          Expenses:Food                                       10.00 USD
+
+        2016-01-01 * "new payee" "narr1"
+          Liabilities:US:Chase:Slate                         -10.00 USD
+          Expenses:Food                                       10.00 USD
+
+        2016-01-01 * "new payee" "narr2"
+          Liabilities:US:Chase:Slate                         -10.00 USD
+          Expenses:Food                                       10.00 USD
 
         2016-02-26 * "Uncle Boons" "Eating out alone"
             Liabilities:US:Chase:Slate                       -24.84 USD
@@ -261,7 +313,7 @@ def test_insert_entry_align(tmpdir):
     ]
 
     transaction = data.Transaction(
-        None,
+        {},
         datetime.date(2016, 1, 1),
         "*",
         "new payee",
