@@ -1,3 +1,5 @@
+# pylint: disable=missing-docstring
+
 import hashlib
 from io import BytesIO
 import os
@@ -14,7 +16,7 @@ def test_api_changed(app, test_client):
 
     result = test_client.get(url)
     response_data = flask.json.loads(result.get_data(True))
-    assert response_data == {"changed": False, "success": True}
+    assert response_data == {"data": False, "success": True}
 
 
 def test_api_add_document(app, test_client, tmpdir):
@@ -24,24 +26,27 @@ def test_api_add_document(app, test_client, tmpdir):
         flask.g.ledger.options["documents"] = [str(tmpdir)]
         request_data = {
             "folder": str(tmpdir),
-            "account": "Test",
-            "file": (BytesIO(b"asdfasdf"), "2015-12-12_test"),
+            "account": "Expenses:Food:Restaurant",
+            "file": (BytesIO(b"asdfasdf"), "2015-12-12 test"),
         }
         url = flask.url_for("json_api.add_document")
 
         response = test_client.put(url)
         assert response.status_code == 400
 
-        filename = os.path.join(str(tmpdir), "Test", "2015-12-12_test")
+        filename = os.path.join(
+            str(tmpdir), "Expenses", "Food", "Restaurant", "2015-12-12 test"
+        )
 
         response = test_client.put(url, data=request_data)
+        print(flask.json.loads(response.get_data(True)))
         assert flask.json.loads(response.get_data(True)) == {
             "success": True,
             "message": "Uploaded to {}".format(filename),
         }
         assert os.path.isfile(filename)
 
-        request_data["file"] = (BytesIO(b"asdfasdf"), "2015-12-12_test")
+        request_data["file"] = (BytesIO(b"asdfasdf"), "2015-12-12 test")
         response = test_client.put(url, data=request_data)
         assert flask.json.loads(response.get_data(True)) == {
             "success": False,
@@ -65,7 +70,7 @@ def test_api_source_put(app, test_client):
     assert response.status_code == 200
 
     path = app.config["BEANCOUNT_FILES"][0]
-    payload = open(path).read()
+    payload = open(path, encoding="utf-8").read()
     sha256sum = hashlib.sha256(open(path, mode="rb").read()).hexdigest()
 
     # change source
@@ -86,7 +91,7 @@ def test_api_source_put(app, test_client):
     assert response_data == {"success": True, "sha256sum": sha256sum}
 
     # check if the file has been written
-    assert open(path).read() == "asdf" + payload
+    assert open(path, encoding="utf-8").read() == "asdf" + payload
 
     # write original source file
     result = test_client.put(
@@ -97,7 +102,7 @@ def test_api_source_put(app, test_client):
         content_type="application/json",
     )
     assert result.status_code == 200
-    assert open(path).read() == payload
+    assert open(path, encoding="utf-8").read() == payload
 
 
 def test_api_format_source(app, test_client):
@@ -106,7 +111,7 @@ def test_api_format_source(app, test_client):
         url = flask.url_for("json_api.format_source")
 
     path = app.config["BEANCOUNT_FILES"][0]
-    payload = open(path).read()
+    payload = open(path, encoding="utf-8").read()
 
     result = test_client.post(
         url,
@@ -120,7 +125,7 @@ def test_api_format_source(app, test_client):
 def test_api_format_source_options(app, test_client):
     # pylint: disable=too-many-function-args
     path = app.config["BEANCOUNT_FILES"][0]
-    payload = open(path).read()
+    payload = open(path, encoding="utf-8").read()
     with app.test_request_context():
         app.preprocess_request()
         url = flask.url_for("json_api.format_source")
